==> pyqt-builder_1.16.3+dfsg.orig.tar.xz: PyQt-builder-1.16.3/docs/releases.md <==
# Release Notes


## v1.16.3

### Link to the stable SIP documentation

The documentation now links to the stable version of the SIP documentation.

Resolves [#11](https://github.com/Python-PyQt/PyQt-builder/issues/11)

### Missing multimedia libraries in Qt v6.7

In Qt v6.7 the QtMultimedia ffmpeg backends depend on new libraries that
were not included in the Qt wheels.  This affected macOS (Qt v6.7.1) and
Windows (Qt v6.7.0).

Resolves [#12](https://github.com/Python-PyQt/PyQt-builder/issues/12)

### Added support for sub-wheels to `pyqt-qt-wheel`

The (undocumented) `pyqt-qt-wheel` utility now supports the splitting of a
project's wheel into the main wheel and a sub-wheel.  Specifying
`--sub-wheel generate` will generate the sub-wheel, and
`--sub-wheel exclude` will generate the main wheel (ie. a normal wheel
without the contents of the sub-wheel).  By default a normal wheel is
generated.


## v1.16.2

### Broken links to SIP documentation

The links to the SIP documentation have been fixed.

### ICU libraries missing from Linux Qt wheels

The ICU libraries were missing from the Linux Qt v6.7 wheels.

Resolves [#10](https://github.com/Python-PyQt/PyQt-builder/issues/10)


## v1.16.1

### Bundle new QtQuick support libraries

The QtQuick3DHelpersImpl, QtQuickControls2MacOSStyleImpl and
QtQuickTimelineBlendTrees libraries added to Qt v6.7.0 are now bundled.

Resolves [#8](https://github.com/Python-PyQt/PyQt-builder/issues/8)

### Missing `LICENSE` file

The missing `LICENSE` file was added.

Resolves [#7](https://github.com/Python-PyQt/PyQt-builder/issues/7)


## v1.16.0

### Migration to GitHub

The project repository has been migrated to
[GitHub](https://github.com/Python-PyQt/PyQt-builder).

PyQt-builder is now licensed under the BSD-2-Clause license.

The project has now been migrated from `setup.py` to `setuptools_scm` and
`pyproject.toml`.

The documentation is now hosted at
[Read the Docs](https://PyQt-builder.readthedocs.io).

Resolves [#1](https://github.com/Python-PyQt/PyQt-builder/issues/1)

### Bundle new QtQuick support libraries

The QtQuickPhysics libraries added to Qt v6.6.0 are now bundled.

The QtQuickControls2 style libraries added to Qt v6.6.3 are now bundled.

Resolves [#6](https://github.com/Python-PyQt/PyQt-builder/issues/6)

### Improvements to example documentation

The example in the documentation no longer uses deprecated features that
will be removed in SIP v7.

The example is now PyQt6-based rather than PyQt5.

Resolves [#5](https://github.com/Python-PyQt/PyQt-builder/issues/5)

### ABI versions

The default ABI versions are now v12.13 and v13.6.

==> pyqt-builder_1.16.4+dfsg.orig.tar.xz: PyQt-builder-1.16.4/docs/releases.md <==
# Release Notes


## v1.16.4

### Support for Windows on Arm for Qt6

Support was added for creating Qt6 wheels for Windows on Arm.

Resolves [#14](https://github.com/Python-PyQt/PyQt-builder/issues/14)

### Support for Linux on Arm for Qt6

Support was added for creating Qt6 wheels for Linux on Arm.

Resolves [#13](https://github.com/Python-PyQt/PyQt-builder/issues/13)


## v1.16.3

### Link to the stable SIP documentation

The documentation now links to the stable version of the SIP documentation.

Resolves [#11](https://github.com/Python-PyQt/PyQt-builder/issues/11)

### Missing multimedia libraries in Qt v6.7

In Qt v6.7 the QtMultimedia ffmpeg backends depend on new libraries that
were not included in the Qt wheels.  This affected macOS (Qt v6.7.1) and
Windows (Qt v6.7.0).

Resolves [#12](https://github.com/Python-PyQt/PyQt-builder/issues/12)

### Added support for sub-wheels to `pyqt-qt-wheel`

The (undocumented) `pyqt-qt-wheel` utility now supports the splitting of a
project's wheel into the main wheel and a sub-wheel.  Specifying
`--sub-wheel generate` will generate the sub-wheel, and
`--sub-wheel exclude` will generate the main wheel (ie. a normal wheel
without the contents of the sub-wheel).  By default a normal wheel is
generated.


## v1.16.2

### Broken links to SIP documentation

The links to the SIP documentation have been fixed.

### ICU libraries missing from Linux Qt wheels

The ICU libraries were missing from the Linux Qt v6.7 wheels.

Resolves [#10](https://github.com/Python-PyQt/PyQt-builder/issues/10)


## v1.16.1

### Bundle new QtQuick support libraries

The QtQuick3DHelpersImpl, QtQuickControls2MacOSStyleImpl and
QtQuickTimelineBlendTrees libraries added to Qt v6.7.0 are now bundled.

Resolves [#8](https://github.com/Python-PyQt/PyQt-builder/issues/8)

### Missing `LICENSE` file

The missing `LICENSE` file was added.

Resolves [#7](https://github.com/Python-PyQt/PyQt-builder/issues/7)


## v1.16.0

### Migration to GitHub

The project repository has been migrated to
[GitHub](https://github.com/Python-PyQt/PyQt-builder).

PyQt-builder is now licensed under the BSD-2-Clause license.

The project has now been migrated from `setup.py` to `setuptools_scm` and
`pyproject.toml`.

The documentation is now hosted at
[Read the Docs](https://PyQt-builder.readthedocs.io).

Resolves [#1](https://github.com/Python-PyQt/PyQt-builder/issues/1)

### Bundle new QtQuick support libraries

The QtQuickPhysics libraries added to Qt v6.6.0 are now bundled.

The QtQuickControls2 style libraries added to Qt v6.6.3 are now bundled.

Resolves [#6](https://github.com/Python-PyQt/PyQt-builder/issues/6)

### Improvements to example documentation

The example in the documentation no longer uses deprecated features that
will be removed in SIP v7.

The example is now PyQt6-based rather than PyQt5.

Resolves [#5](https://github.com/Python-PyQt/PyQt-builder/issues/5)

### ABI versions

The default ABI versions are now v12.13 and v13.6.
